Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FindFontFile ¶
FindFontFile finds font files based on the specified language.
It takes a language code as a parameter and returns a slice of strings representing the file paths of the font files. If no font files are found, an error is returned.
params: language string, e.g. "en", "fr", "de", etc.
if language is "", the system language is used.
See https://www.microsoft.com/typography/otspec/languagetags.htm
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.